@@ -13,6 +13,7 @@
 
 #include "pxr/usd/sdf/path.h"
 
+#include "pxr/base/tf/spinMutex.h"
 #include "pxr/base/tf/staticTokens.h"
 #include "pxr/base/tf/token.h"
 
@@ -98,6 +99,7 @@ protected:
 
 private:
     std::atomic_bool _primvarsBuilt;
+    TfSpinMutex _primvarsMutex;
     bool _extComputationPrimvarsBuilt : 1;
 
     HdContainerDataSourceAtomicHandle _primvars;
