@@ -14,11 +14,7 @@
 #include "pxr/base/gf/matrix4f.h"
 #include "pxr/base/vt/array.h"
 
-#if defined(EMBREE_MAJOR_VERSION) && EMBREE_MAJOR_VERSION >= 4
-    #include <embree4/rtcore.h>
-#else
-    #include <embree4/rtcore.h>
-#endif // defined(EMBREE_MAJOR_VERSION) && EMBREE_MAJOR_VERSION >= 4
+#include <embree4/rtcore.h>
 
 PXR_NAMESPACE_OPEN_SCOPE
 
