@@ -49,7 +49,9 @@ public:
 
     /// Checks to see if the embree plugin is supported on the running system
     ///
-    bool IsSupported(bool gpuEnabled = true) const override;
+    bool IsSupported(
+        HdRendererCreateArgs const &rendererCreateArgs,
+        std::string *reasonWhyNot = nullptr) const override;
 
 private:
     // This class does not support copying.
