@@ -1,25 +1,8 @@
 //
 // Copyright 2019 Pixar
 //
-// Licensed under the Apache License, Version 2.0 (the "Apache License")
-// with the following modification; you may not use this file except in
-// compliance with the Apache License and the following modification to it:
-// Section 6. Trademarks. is deleted and replaced with:
-//
-// 6. Trademarks. This License does not grant permission to use the trade
-//    names, trademarks, service marks, or product names of the Licensor
-//    and its affiliates, except as required to comply with Section 4(c) of
-//    the License and to reproduce the content of the NOTICE file.
-//
-// You may obtain a copy of the Apache License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the Apache License with the above modification is
-// distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-// KIND, either express or implied. See the Apache License for the specific
-// language governing permissions and limitations under the Apache License.
+// Licensed under the terms set forth in the LICENSE.txt file available at
+// https://openusd.org/license.
 //
 #ifndef PXR_USD_USD_COLLECTION_MEMBERSHIP_QUERY_H
 #define PXR_USD_USD_COLLECTION_MEMBERSHIP_QUERY_H
@@ -113,10 +96,10 @@ public:
 
     /// Returns a set of paths for all collections that were included in the
     /// collection from which this Usd_CollectionMembershipQueryBase object was
-    /// computed. This set is recursive, so collections that were included
-    /// by other collections will be part of this set. The collection from
-    /// which this Usd_CollectionMembershipQueryBase object was computed is *not*
-    /// part of this set.
+    /// computed. This set is recursive, so collections that were included by
+    /// other collections will be part of this set. The collection from which
+    /// this Usd_CollectionMembershipQueryBase object was computed is *not* part
+    /// of this set.
     const SdfPathSet& GetIncludedCollections() const {
         return _includedCollections;
     }
@@ -168,6 +151,13 @@ protected:
     bool _hasExcludes=false;
 };
 
+/// Compute an SdfPathExpression that matches the same paths as \p ruleMap.  The
+/// resulting SdfPathExpression is always complete (see
+/// SdfPathExpression::IsComplete()) and never contains predicates.
+USD_API
+SdfPathExpression
+UsdComputePathExpressionFromCollectionMembershipQueryRuleMap(
+    Usd_CollectionMembershipQueryBase::PathExpansionRuleMap const &ruleMap);
 
 // -------------------------------------------------------------------------- //
 // UsdCollectionMembershipQuery                                               //
@@ -310,10 +300,10 @@ public:
         // compare equal to each other.  This is because the evaluator objects
         // run code, and there's no good way to determine equivalence.
         return _topExpansionRule == rhs._topExpansionRule &&
-        _hasExcludes == rhs._hasExcludes &&
-        _pathExpansionRuleMap == rhs._pathExpansionRuleMap &&
-        _includedCollections == rhs._includedCollections &&
-        _exprEval.IsEmpty() == rhs._exprEval.IsEmpty();
+            _hasExcludes == rhs._hasExcludes &&
+            _pathExpansionRuleMap == rhs._pathExpansionRuleMap &&
+            _includedCollections == rhs._includedCollections &&
+            _exprEval.IsEmpty() == rhs._exprEval.IsEmpty();
         ;
     }
 
@@ -343,12 +333,6 @@ private:
 ///
 /// \brief Evaluates SdfPathExpressions with objects from a given UsdStage.
 class UsdObjectCollectionExpressionEvaluator {
-    struct ObjToPath {
-        SdfPath operator()(UsdObject const &obj) const {
-            return obj.GetPath();
-        }
-    };
-    
     struct PathToObj {
         UsdObject operator()(SdfPath const &path) const {
             return stage->GetObjectAtPath(path);
@@ -359,7 +343,7 @@ class UsdObjectCollectionExpressionEvaluator {
 public:
     using PathExprEval = SdfPathExpressionEval<UsdObject>;
     using IncrementalSearcher =
-        typename PathExprEval::IncrementalSearcher<ObjToPath, PathToObj>;
+        typename PathExprEval::IncrementalSearcher<PathToObj>;
     
     /// Construct an empty evaluator.
     UsdObjectCollectionExpressionEvaluator() = default;
